### NMachine Telemetry Plugin

The KAMA telemetry is an out-of-the-box NMachine plugin. When enabled, a
persistent store is used to track changes in application's status,
variables, and preferences. You can use this to audit the application,
and perform rollbacks.

A subset of the telemetry is also uploaded to the publisher, in case
they need to remotely troubleshoot your installation.
